@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 import dbus, gobject
-from ifaceswlib.interfaces.Abstract import AbstractInterface
+from advifswlib.interfaces.Abstract import AbstractInterface
 from advpowcommon.util.execn import *
 
 class WLANInterface(AbstractInterface):
